@@ -3,7 +3,7 @@ from .feature_runner import FeatureRunner
 from ipclassifier.dataprep import RawFileProcessor
 from ipclassifier.classifier import Classifier
 
-##### use local copy of nltk_data
+##### use local copy of nltk_data if not elsewhere
 import nltk
 import os
 local_path = os.path.join("".join(os.path.dirname(__file__).split('/runners')[0]),  "nltk_data")
@@ -26,5 +26,5 @@ def classify_ip(filename):
         print(f"Your text is probably {c.guessed_period}")
         return c.guessed_period
     else:
-        raise FileNotFoundError("Please make sure your file is in the user_input_poems/ folder.")
+        raise FileNotFoundError("Please make sure your filepath is correct.")
 
